@@ -32,7 +32,7 @@
 #include <stdlib.h>
 #endif
 
-#if (defined(solaris) && defined( __LP64__ )) || defined(__s390x__) || defined(FreeBSD)
+#if (defined(solaris) && defined( __LP64__ )) || defined(__s390x__) || defined(__FreeBSD__)
 /* If we are building for 64-bit Solaris, all functions that return pointers
  * must be declared before they are used; otherwise the compiler will assume
  * that they return ints and the top 32 bits of the pointer will be lost,
@@ -91,10 +91,7 @@ void do_label(int,char *,int,int);
 /*	  column							*/
 /************************************************************************/
 
-char libbif_version[] = "Libbif Version $Revision: 3.27 $";
-void do_eof(int );		/* Used internally */
-void do_header(int );		/* Used internally */
-int endian(void);
+char libbif_version[] = "Libbif Version $Revision: 3.30 $";
 #endif
 
 #define BOF 0x9
@@ -158,6 +155,28 @@ struct float_record {		/* Type 3 record */
 	char rgblo;
 	double data;
 	};
+
+#ifdef HAVE_ANSIC_C
+void close_xls(int);
+int create_xls(char *);
+void do_header(int);
+void do_int(int, int, int, int);
+void do_float(int, double, int, int);
+void do_label(int, char *, int, int );
+void do_eof(int) ;
+int endian(void);
+#else
+void
+close_xls();
+int create_xls();
+void do_header();
+void do_int();
+void do_float();
+void do_label();
+void do_eof();
+int endian();
+#endif
+
 /*
  * Write the EOF and close the file 
  */
@@ -166,6 +185,7 @@ void
 close_xls(int fd)
 {
 #else
+void
 close_xls(fd)
 int fd;
 {
